# exb-sdk

[![ci](https://img.shields.io/github/actions/workflow/status/ExB-Group/exb-sdk/ci-main.yaml?style=for-the-badge&branch=main&logo=github&logoColor=white)](https://github.com/ExB-Group/exb-sdk/actions/workflows/ci-main.yaml?query=branch%3Amain)

[![version](https://img.shields.io/pypi/v/exb-sdk?style=for-the-badge&logo=pypi&logoColor=white)](https://pypi.org/project/exb-sdk)
[![pyversions](https://img.shields.io/pypi/pyversions/exb-sdk?style=for-the-badge&logo=python&logoColor=white)](https://github.com/ExB-Group/exb-sdk)
[![license](https://img.shields.io/pypi/l/exb-sdk?style=for-the-badge)](https://github.com/ExB-Group/exb-sdk/LICENSE)

[![docs](https://img.shields.io/badge/docs-blue?style=for-the-badge&label=sphinx&logo=sphinx&logoColor=white)](https://ExB-Group.github.io/exb-sdk)
[![pdm](https://img.shields.io/badge/managed-blue?style=for-the-badge&logo=pdm&logoColor=white&label=pdm&color=%237e56c2)](https://pdm-project.org)
[![ruff](https://img.shields.io/badge/formatted-blue?style=for-the-badge&logo=ruff&logoColor=white&label=ruff&color=%23d7ff64)](https://astral.sh/ruff)

## What is exb-sdk?
<!-- start description -->

SDK for working with ExB (app.exb.de)

<!-- end description -->

## Features
<!-- start features -->

<!-- end features -->

## Installation
<!-- start installation -->

exb-sdk can be installed with `pip`:

```text
pip install exb-sdk
```

<!-- end installation -->

## Quickstart
<!-- start quickstart -->

<!-- end quickstart -->

## Contributing
